@@ -5,14 +5,16 @@ def sh(*args)
   system(*args)
 end
 
-spec = "vendor/rabbitmq-codegen/amqp-rabbitmq-0.9.1.json"
+extensions = []
+
+spec = "codegen/rabbitmq-codegen/amqp-rabbitmq-0.9.1.json"
 unless File.exist?(spec)
   sh "git submodule update --init"
 end
 
 path = "lib/amq/protocol/client.rb"
-sh "./codegen.py client #{spec} #{path}"
+puts "Running ./codegen/codegen.py client #{spec} #{path}"
+sh "./codegen/codegen.py client #{spec} #{extensions.join(' ')} #{path}"
 if File.file?(path)
-  sh "./post-processing.rb #{path}"
   sh "ruby -c #{path}"
 end
