@@ -41,11 +41,11 @@ module AMQ
             buffer << TYPE_HASH
             buffer << self.encode(value)
           else
-            buffer << TableValueEncoder.encode(value)
+            buffer << TableValueEncoder.encode(value).force_encoding(buffer.encoding)
           end
         end
 
-        [buffer.bytesize].pack(PACK_UINT32) + buffer
+        [buffer.bytesize].pack(PACK_UINT32).force_encoding(buffer.encoding) + buffer
       end
 
 
@@ -66,6 +66,12 @@ module AMQ
                        when TYPE_STRING
                          v, offset = TableValueDecoder.decode_string(data, offset)
                          v
+                       when TYPE_BYTE_ARRAY
+                         # Ruby doesn't have a direct counterpart to
+                         # ByteBuffer or byte[], so using a string feels
+                         # more appropriate than an array of fixnums
+                         v, offset = TableValueDecoder.decode_string(data, offset)
+                         v
                        when TYPE_INTEGER
                          v, offset = TableValueDecoder.decode_integer(data, offset)
                          v
