@@ -12,7 +12,7 @@ module AMQ
             Select.decode("\x01")
           end
           
-          its(:nowait) { should be_true }
+          its(:nowait) { should be_truthy }
         end
         
         describe '.encode' do
@@ -20,8 +20,8 @@ module AMQ
             channel = 1
             nowait = true
             method_frame = Select.encode(channel, nowait)
-            method_frame.payload.should == "\x00U\x00\n\x01"
-            method_frame.channel.should == 1
+            expect(method_frame.payload).to eq("\x00U\x00\n\x01")
+            expect(method_frame.channel).to eq(1)
           end
         end
       end
@@ -34,8 +34,8 @@ module AMQ
           it 'encodes the parameters into a MethodFrame' do
             channel = 1
             method_frame = SelectOk.encode(channel)
-            method_frame.payload.should == "\000U\000\v"
-            method_frame.channel.should == 1
+            expect(method_frame.payload).to eq("\000U\000\v")
+            expect(method_frame.channel).to eq(1)
           end
         end
       end
